@@ -1,7 +1,7 @@
 package App::cryp::exchange;
 
 our $DATE = '2018-06-11'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,7 +65,7 @@ our %arg_req2_type = (
 
 our %arg_req3_price = (
     price => {
-        schema => ['float*', xmin=>0],
+        schema => ['float*', xmin=>0, 'x.perl.coerce_rules'=>['str_num_en']],
         req => 1,
         pos => 3,
     },
@@ -74,11 +74,11 @@ our %arg_req3_price = (
 our %args_size = (
     base_size => {
         summary => 'Order amount, denominated in base currency (first currency of the pair)',
-        schema => ['float*', xmin=>0],
+        schema => ['float*', xmin=>0, 'x.perl.coerce_rules'=>['str_num_en']],
     },
     quote_size => {
         summary => 'Order amount, denominated in quote currency (second currency of the pair)',
-        schema => ['float*', xmin=>0],
+        schema => ['float*', xmin=>0, 'x.perl.coerce_rules'=>['str_num_en']],
     },
 );
 
@@ -364,7 +364,7 @@ App::cryp::exchange - Interact with cryptoexchanges using a common interface
 
 =head1 VERSION
 
-This document describes version 0.006 of App::cryp::exchange (from Perl distribution App-cryp-exchange), released on 2018-06-11.
+This document describes version 0.007 of App::cryp::exchange (from Perl distribution App-cryp-exchange), released on 2018-06-11.
 
 =head1 SYNOPSIS
 
